@@ -161,6 +161,7 @@ History:
 2011-08-29 ROwen    Bug fix: display was incorrect unless data array was 32-bit float.
 2012-07-09 ROwen    Modified to use RO.TkUtil.Timer.
 2012-11-13 ROwen    Stop using Checkbutton indicatoron=False because it is no longer supported on MacOS X.
+2013-09-05 ROwen    Change "import Image" to "from PIL import Image" for compatibility with Pillow.
 """
 import weakref
 import Tkinter
@@ -172,7 +173,7 @@ except ImportError:
     # old versions of numpy had ma buried
     import numpy.core.ma as ma
 import os.path
-import Image
+from PIL import Image
 import ImageTk
 import RO.AddCallback
 import RO.CanvasUtil
